#include <Adafruit_NeoPixel.h>
#ifdef __AVR__
#include <avr/power.h> 
#endif

#define PIN        25 

#define NUMPIXELS 16 // Popular NeoPixel ring size
Adafruit_NeoPixel pixels(NUMPIXELS, PIN, NEO_GRB + NEO_KHZ800);

#define DELAYVAL 500 // Time (in milliseconds) to pause between pixels

#include <SPI.h>
#include "Adafruit_MAX31855.h"

// digital IO pins.
#define MAXDO   19
#define MAXCS_1   26
#define MAXCS_2   27
#define MAXCLK  18

// initialize the Thermocouple
Adafruit_MAX31855 thermocouple_1(MAXCLK, MAXCS_1, MAXDO);
Adafruit_MAX31855 thermocouple_2(MAXCLK, MAXCS_2, MAXDO);


void setup() {
  Serial.begin(115200);

  pinMode(32, INPUT);
  pinMode(22, INPUT);
  pinMode(21, INPUT);

  pinMode(13, OUTPUT);
  pinMode(23, OUTPUT);
   
  pixels.begin(); // INITIALIZE NeoPixel strip object (REQUIRED)

  Serial.println("MAX31855 test");
  delay(500);

  Serial.print("Initializing sensor...");
  if (!thermocouple_1.begin()) {
    Serial.println("ERROR.");
    while (1) delay(10);
  }

  Serial.print("Initializing sensor...");
  if (!thermocouple_2.begin()) {
    Serial.println("ERROR.");
    while (1) delay(10);
  }
  Serial.println("DONE.");

  pixels.clear(); 
  pixels.setPixelColor(0, pixels.Color(255, 0, 0));
  pixels.show();   // Send the updated pixel colors to the hardware.
  delay(1000);
  pixels.setPixelColor(0, pixels.Color(0, 255, 0));
  pixels.show();   // Send the updated pixel colors to the hardware.
  delay(1000);
  pixels.setPixelColor(0, pixels.Color(0, 0, 255));
  pixels.show();   // Send the updated pixel colors to the hardware.
  delay(1000);
}

void loop() {
  double c1 = thermocouple_1.readCelsius();
  double c2 = thermocouple_2.readCelsius();

  if (isnan(c1)) {
    Serial.println("Thermocouple fault(s) detected!");
    uint8_t e = thermocouple_1.readError();
    if (e & MAX31855_FAULT_OPEN) Serial.println("FAULT: Thermocouple is open - no connections.");
  } else {
    Serial.print("C1 = ");
    Serial.println(c1);
  }

  if (isnan(c2)) {
    Serial.println("Thermocouple fault(s) detected!");
    uint8_t e = thermocouple_2.readError();
    if (e & MAX31855_FAULT_OPEN) Serial.println("FAULT: Thermocouple is open - no connections.");
  } else {
    Serial.print("C2 = ");
    Serial.println(c2);
  }

  delay(200);
  digitalWrite(13, HIGH);
  digitalWrite(23, LOW);
  delay(1000);
  digitalWrite(23, HIGH);
  digitalWrite(13, LOW);
  delay(1000);
  Serial.println("");

  Serial.println("--------------------------------------------------");
  Serial.print(digitalRead(32)); Serial.print(digitalRead(22)); Serial.print(digitalRead(21));//Serial.print(digitalRead(35));
  Serial.println("");
  Serial.println("--------------------------------------------------");

  delay(1000);
}
